"use strict";
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const aws_sdk_1 = require("aws-sdk");
const bucket_1 = tslib_1.__importDefault(require("./bucket"));
const console_1 = tslib_1.__importDefault(require("./formatters/console"));
const csv_1 = tslib_1.__importDefault(require("./formatters/csv"));
class S3Audit extends command_1.Command {
    async run() {
        const { flags } = this.parse(S3Audit);
        const buckets = [];
        const format = flags.format;
        if (flags.bucket) {
            return this.auditBuckets(format, [new bucket_1.default(flags.bucket)]);
        }
        new aws_sdk_1.S3().listBuckets((error, data) => {
            if (!data || data.Buckets === undefined) {
                return this.exit();
            }
            data.Buckets.forEach(bucket => {
                if (bucket.Name !== undefined) {
                    buckets.push(new bucket_1.default(bucket.Name));
                }
            });
            this.auditBuckets(format, buckets);
        });
    }
    auditBuckets(format, buckets) {
        let formatter;
        switch (format) {
            case 'csv':
                formatter = new csv_1.default((output) => {
                    this.log(output);
                });
                break;
            default:
                formatter = new console_1.default();
        }
        formatter.run(buckets);
    }
}
S3Audit.description = 'Audits S3 bucket settings';
S3Audit.args = [];
S3Audit.examples = [
    '$ s3audit',
    '$ s3audit --bucket=s3-bucket=name',
    '$ s3audit --format=csv',
];
S3Audit.flags = {
    bucket: command_1.flags.string({
        description: 'The name of a bucket to target'
    }),
    format: command_1.flags.string({
        description: 'The output format to use',
        default: 'console',
        options: ['console', 'csv']
    }),
    version: command_1.flags.version({ char: 'v' }),
    help: command_1.flags.help({ char: 'h' }),
};
S3Audit.usage = 's3audit --bucket=s3-bucket-name --output=csv';
module.exports = S3Audit;
